@@ -73,6 +73,7 @@ def common(**kwargs):
 
     MIDDLEWARE = [
         'django.middleware.common.CommonMiddleware',
+        "django.middleware.csrf.CsrfViewMiddleware",
         'django.contrib.sessions.middleware.SessionMiddleware',
         'django.contrib.auth.middleware.AuthenticationMiddleware',
         'django.contrib.flatpages.middleware.FlatpageFallbackMiddleware',
@@ -97,7 +98,6 @@ def common(**kwargs):
         'waffle',
         'smoketest',
         'gunicorn',
-        'django_markwhat',
     ]
 
     STATIC_URL = "/media/"
